# ☢️ PYSCX

![Технический банне](https://github.com/user-attachments/assets/a82243e5-6f38-46a9-89bd-453bb051b557)

![GitHub Release](https://img.shields.io/github/v/release/Oidaho/pyscx)
![GitHub Downloads](https://img.shields.io/github/downloads/Oidaho/pyscx/total)

![GitHub watchers](https://img.shields.io/github/watchers/oidaho/pyscx)
![GitHub Repo stars](https://img.shields.io/github/stars/Oidaho/pyscx)

Данная библиотека разработана для упрощения взаимодействия с STALCRAFT: X API, предоставляя надежный и удобный интерфейс, ориентированный на потребности разработчиков.
Она обеспечивает эффективный доступ к игровым данным, позволяя легко интегрировать их в ваши проекты.

Независимо от того, разрабатываете ли вы специализированные инструменты, анализируете игровую статистику или создаете пользовательские приложения, библиотека предлагает интуитивно понятный и технически грамотный подход к получению и обработке данных STALCRAFT: X.
Ее архитектура ориентирована на повышение производительности разработки и минимизацию сложностей, связанных с интеграцией API.

> [!NOTE]
> STALCRAFT: X API - v1.1.0
>
> Python 3.13+

---

## ✨ Features

- **Интуитивный интерфейс взаимодействия**  
  Библиотека разработана с акцентом на простоту и удобство использования, что позволяет вам сосредоточиться на создании качественных решений и уникального контента.  
- **Полная поддержка всех конечных точек API**  
  Обеспечивается доступ ко всем доступным конечным точкам STALCRAFT: X API, что позволяет использовать весь функционал без ограничений.  
- **Автоматическая обертка данных**  
  Данные предоставляются в структурированном формате, готовом к непосредственному использованию в ваших проектах.  
- **Гибкая система управления токенами**  
  Реализована удобная настройка и управление токенами API, что обеспечивает простую интеграцию и безопасность ваших запросов.  

## 📦 Установка

Чтобы установить библиотеку, выполните следующую команду:

```bash
pip install pyscx
```

Или, если вы хотите установить библиотеку непосредственно с GitHub:

```bash
pip install git+https://github.com/Oidaho/pyscx.git
```

## 🛠️ Быстрый Старт

Вот краткий пример, который поможет вам начать:

```python
import os
from dotenv import load_dotenv

from pyscx import Server, API
from pyscx.token import Token, TokenType


load_dotenv()

app_token = Token(
    value=os.getenv("DEMO_APP_ACCESS_TOKEN"),
    type=TokenType.APPLICATION,
)
user_token = Token(
    value=os.getenv("DEMO_USER_ACCESS_TOKEN"),
    type=TokenType.USER,
)


api = API(server=Server.DEMO, tokens=[user_token, app_token])

print(api.clans(region="EU").get_all())
```

## 📚 Документация

Для получения подробной документации перейдите на [официальную страницу](https://Oidaho.github.io/pyscx/) документации репозитория.

## 🚀 Идеи проектов

Вот несколько интересных проектных идей, которые можно реализовать при помощи `pyscx`:

- **Анализатор аукциона**: Создайте инструмент для отслеживания цен на товары и поиска выгодных предложений.
- **Отслеживание выбросов**: Создайте систему уведомлений о времени начала и окончания выбросов.
- **Панель мониторинга статистики игроков**: Разработайте панель мониторинга для анализа статистики игроков.
- **Социальный трекер**: Программно отслеживайте друзей и их статистику.

## 🤝 Помощь в разработке

Мы приветствуем любой вклад в разработку `pyscx`! Если у вас есть идеи, предложения или вы обнаружили ошибку - пожалуйста, создайте в разделе [issues](https://github.com/Oidaho/pyscx/issues) новую запись.

## 📜 Лицензия

Этот проект лицензирован в соответствии с [GPL-3.0 License](https://github.com/Oidaho/pyscx/blob/main/LICENSE).
